%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% hsbounds.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [u,v,F1,F2] = hsbounds(prob)
% gives the bounds on the variables and constraints for the 
% Hock-Schittkowski function number prob
%
% Input:
% prob   number of problem
%        at present, prob in {18,19,23,30,31,34,36,37,41,53,60,65,66,
%        71,74,111,217} is implemented
% 
% Output:
% u,v    bounds on the variables
% F1,F2  bounds on the constraints
%
function [u,v,F1,F2] = hsbounds(prob)
if prob == 18
  u = [2; 0];
  v = [50; 50];
  F1 = [0; 0];
  F2 = [Inf; Inf];
elseif prob == 19
  u = [13; 0];
  v = [100; 100];
  F1 = [0; 0];
  F2 = [Inf; Inf];
elseif prob == 23
  u = [-50; -50];
  v = [50; 50];
  F1 = zeros(5,1);
  F2 = Inf*F1;
elseif prob == 30
  u = [1; -10; -10];
  v = 10*ones(3,1);
  F1 = 0;
  F2 = Inf;
elseif prob == 31
  u = [-10; 1; -10];
  v = [10; 10; 1];
  F1 = 0;
  F2 = Inf;
elseif prob == 34
  u = zeros(3,1);
  v = [100; 100; 10];
  F1 = [0; 0];
  F2 = [Inf; Inf];
elseif prob == 36
  u = zeros(3,1);
  v = [20; 11; 42];
  F1 = 0;
  F2 = Inf;
elseif prob == 37
  u = zeros(3,1);
  v = 42*ones(3,1);
  F1 = [0; 0];
  F2 = [Inf; Inf];
elseif prob == 41
  u = zeros(4,1);
  v = [ones(3,1); 2];
  F1 = 0;
  F2 = 0;
elseif prob == 53
  u = -10*ones(5,1);
  v = 10*ones(5,1);
  F1 = zeros(3,1);
  F2 = Inf*ones(3,1);
elseif prob == 60
  u = -10*ones(3,1);
  v = 10*ones(3,1);
  F1 = 0;
  F2 = 0;
elseif prob == 65
  u = [-4.5; -4.5; -5];
  v = [4.5; 4.5; 5];
  F1 = 0;
  F2 = Inf;
elseif prob == 66
  u = zeros(3,1);
  v = [100; 100; 10];
  F1 = [0; 0];
  F2 = [Inf; Inf];
elseif prob == 71
  u = ones(4,1);
  v = 5*ones(4,1);
  F1 = [0; 0];
  F2 = [Inf; 0];
elseif prob == 74 
  a = 0.55;
  u = [0; 0; -a; -a];
  v = [1200; 1200; a; a];
  F1 = zeros(5,1);
  F2 = [Inf; Inf; zeros(3,1)];
elseif prob == 111
  u = -100*ones(10,1);
  v = 100*ones(10,1);
  F1 = zeros(3,1);
  F2 = zeros(3,1);
else
  error('Problem not coded!')
end
