%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobacc.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function acc = snobacc(x,f,g,G)
% computes a measure of the accuracy of a quadratic model
%
% Input:
% x	x(1,:) is the point around which a quadratic model has been
%	estimated and x(j,:), j=2:size(x,1), are a set of other points
% f	f(j) is the function value pertaining to x(j,:)
% g	coefficients of the quadratic model
% G	matrix proportional to the Hessian
%	the quadratic model is q(y) = g(1) + (y-x0)*g(2:n+1) 
%	+ 0.5*g(n+2)*(y-x0)*G*(y-x0), where x0 = x(j,:), n = size(x,2)
%
% Output:
% acc	estimated accuracy
%	= max(abs(q(x(j,:))-f(j))), j=1:size(x,1) 
%
function acc = snobacc(x,f,g,G)
n = size(x,2);
acc = abs(f(1)-g(1));
for j=2:size(x,1)
  f1 = g(1) + (x(j,:)-x(1,:))*g(2:n+1)' + 0.5*g(n+2)*(x(j,:)-x(1,:))*G*(x(j,:)-x(1,:))';
  acc = max(acc,abs(f1-f(j)));
end
