%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobbeta.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function beta = snobbeta(x,jbest,L,beta)
% computes the values beta(j) = norm(L*(x(j,:)-xbest)')^2 for the new
% points 
%
% Input:
% x	the rows are a set of points
% jbest	pointer to the best point
% L 	Cholesky factor from snobhess
% beta	vector containing the beta-values for the old points
%
% Output:
% beta	updated version of beta
%
function beta = snobbeta(x,jbest,L,beta)
xbest = x(jbest,:);
nold = length(beta);
beta(nold+1:size(x,1)) = sum((L*(x(nold+1:size(x,1),:)-ones(size(x,1)-nold,1)*xbest)').^2,1)';
