%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobpoint.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function y = snobpoint(x,xl,xu,g,G,u,v)
% for a box [xl,xu] containing a point x, a point y in the intersection 
% of [xl,xu] and [u,v] is constructed such that it is both not close to 
% x and to the boundary of [xl,xu] and its function value is estimated
% from a local quadratic model around x
%
% Input:
% x	point contained in [xl,xu]
% xl,xu	box bounds
% u,v   the point is to be generated in [u,v]
% g,G   the local quadratic model around x is given by
%       q(y) = g(1) + g(2:n+1)*(y-x)' + 0.5*g(n+2)*(y-x)*G*(y-x)
%       for a row vector y
%
% Output:
% y	point in the intersection of [xl,xu] and [u,v]
% f     corresponding estimated function value
%
function [y,f] = snobpoint(x,xl,xu,g,G,u,v)
n = length(x);
for i=1:n
  if x(i) - xl(i) > xu(i) - x(i)
    y(i) = 0.5*(xl(i)+x(i));
  else
    y(i) = 0.5*(x(i)+xu(i));
  end
end
y = min(max(y,u),v);
y = snobround(y,max(xl,u),min(xu,v));
f = g(1) + g(2:n+1)*(y-x)' + 0.5*g(n+2)*(y-x)*G*(y-x)';
