%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobround.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function x = snobround(x,u,v)
% a point x is projected into the interior of [u,v] and its entries are
% rounded to the nearest integer
%
% Input:
% x	vector 
% u,v	vectors of the same length as x such that u < v
%
% Output:
% x	projected and rounded version of x
%
function x = snobround(x,u,v)
x = min(max(x,u),v);
x = round(x);
i1 = find(x<u);
if ~isempty(i1)
  x(i1) = x(i1) + 1;
end
i2 = find(x>v);
if ~isempty(i2)
  x(i2) = x(i2) - 1;
end
