%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobscal.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [u,v,u1,v1,x,dy] = snobscal(u,v,u1,v1,x,dx,dy)
% scales the vectors u, v, u1, v1 and dy with the vector dx 
% 
% Input
% u,v,u1,v1,dx,dy   vectors of same length n, where dx has only
%                   positive entries
% x                 matrix with n columns
%
% Output:
% u,v,u1,v1,x,dy    the old quantities scaled by dx
% 
function [u,v,u1,v1,x,dy] = snobscal(u,v,u1,v1,x,dx,dy)
nx = size(x,1);
u = u./dx;
v = v./dx;
u1 = u1./dx;
v1 = v1./dx;
x = x./(ones(nx,1)*dx);
dy = dy./dx;

