%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobstd.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function sigma = snobstd(x,x0,f,sigmag2,sigmaG2,L)
% estimation of the standard deviation of an estimated function value
%
% Input:
% x	       point at which the standard deviation of the estimated 
%	       function value is to be estimated
% x0	       point around which the quadratic model has been estimated
% f	       vector containing the deviations of the function values
%	       of the neighbors of x0
% sigmag2      estimated variance of the local fit
% sigmaG2      estimated variance of the Hessian fit
% L	       Cholesky factor of the estimated Hessian
%
% Output:
% sigma	       estimated standard deviation
%
function sigma = snobstd(x,x0,f,sigmag2,sigmaG2,L)
sigma = sqrt(sigmag2*(sum(f.^2)/length(f)+sigmaG2*norm(L*(x-x0)')^4));
