%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% snobtest.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% file (m-script) for running SNOBFIT on a set of test functions 
clear; clear global; clear mex
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% beginning of data to be adapted
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fcn = 'bra';       % select test function
                   % bra  n=2   Branin
                   % cam  n=2   six-hump camel
                   % gpr  n=2   Goldstein-Price   
                   % shu  n=2   Shubert
                   % hm3  n=3   Hartman 3
                   % s10  n=4   Shekel 10
                   % sh5  n=4   Shekel 5
                   % sh7  n=4   Shekel 7
                   % hm6  n=6   Hartman 6
file = 'branin';   % the intermediate data (after each call to SNOBFIT)
                   % are stored in branin.mat
[u,v,fglob] = defaults(fcn); 
                   % default box bounds and best function value
n = length(u);     % dimension of the problem;
ncall = 10000;     % limit on the number of function calls
npoint = n+6;      % number of random start points to be generated
nreq = n+6;        % number of points to be generated in the 
                   % continuation calls to SNOBFIT
fac = 0;           % factor for multiplicative perturbation of the data
dx = (v-u)'*1.e-4; % resolution vector
p = 0.1;           % fraction of points of class 4 among the points of 
                   % class 3 and 4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% end of data to be adapted
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

params = struct('bounds',{u,v},'nreq',nreq,'p',p); % input structure

% generate points for the initial call and compute their function values
x = rand(npoint,n);
x = x*diag(v-u) + ones(npoint,1)*u';
for j=1:npoint
  f(j,:) = [feval(fcn,x(j,:))+fac*randn max(sqrt(eps),3*fac)];
end

ncall0 = npoint; % function call counter

while ncall0 < ncall % repeat until the limit on function calls is reached
  if ncall0 == npoint
    [request,xbest,fbest,acc] = snobfit(file,x,f,params,dx); % initial call
  else
    [request,xbest,fbest,acc] = snobfit(file,x,f,params); % continuation call
  end
  req = request(:,[1:n+1 n+3]) % show the suggested points, estimated 
                               % function values and class
  clear x; clear f;
  % compute (perturbed) function values at the suggested points
  for j=1:size(request,1)
    x(j,:) = request(j,1:n);
    f(j,:) = [feval(fcn,x(j,:))+fac*randn max(sqrt(eps),3*fac)];
  end
  ncall0 = ncall0 + size(request,1); % update function call counter
  [fbestn,jbest] = min(f(:,1));  % best of the new function values
  % if a better function value has been found, update fbest 
  if fbestn < fbest
    fbest = fbestn;
    xbest = x(jbest,:);
    xbest,fbest % display current best point and function value if it
                % has changed
  end 
  if fglob % check stopping criterion (best function value is found
           % with a relative error < 1.e-2)
    if (fbest-fglob)/abs(fglob) < 1.e-2,xbest,fbest,break,end
  else % safeguard if functions with fglob = 0 are added by the user
    if abs(fbest) < 1.e-5,xbest,fbest,break,end
  end
end
xbest,fbest % display best point and function value
ncall0  % display number of function values used
