%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% defaults.m %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [u,v,fglob,xglob] = defaults(fcn)
% sets the default values for the dimension n and the default original
% box [u,v] for the functions fcn in {'ad4','bra','cam','cor','dj1',
% 'dj3','dj4','dj5','gpr','gri','hm3','hm6','mla','pol','ros','s10',
% 'sch','sgr','sh5','sh7','shu','zim'}
% for all these functions except 'ad4', in addition the global variables
% fglob, xglob and nglob are defined
function [u,v,fglob,xglob] = defaults(fcn)
%global nglob xglob
% fglob        global minimum of fcn
% nglob        number of global minimizers in the box [u,v]
% xglob(1:n,1:nglob)  xglob(:,i), i = 1:nglob, are the global
%              minimizers of a test function fcn in [u,v]
if fcn == 'gpr'      % Goldstein-Price
  u = [-2; -2]; 
  v = [2; 2]; %v = [Inf; Inf]; u = -v;
  fglob = 3;
  xglob = [0.; -1.];
  nglob = 1;
elseif fcn == 'bra'  % Branin
  u = [-5; 0];
  v = [10; 15]; %v = [Inf; Inf]; u = -v;
  fglob = 0.397887357729739;
  xglob = [9.42477796   -3.14159265  3.14159265; 
           2.47499998   12.27500000  2.27500000];
  nglob = 3;  
elseif fcn == 'cam'  % Six-hump camel
  u = [-3; -2];
  v = [3; 2]; %v = [Inf; Inf]; u = -v;
  fglob = -1.0316284535;
  xglob = [ 0.08984201  -0.08984201;
           -0.71265640   0.71265640];
  nglob = 2;
elseif fcn == 'shu'  % Shubert
  n = 2;
  u = [-10; -10];
  v = [10; 10]; %v = [Inf; Inf]; u = -v;
  fglob = -186.730908831024;
  xglob = [
-7.08350658  5.48286415  4.85805691  4.85805691 -7.08350658 -7.70831382 -1.42512845 -0.80032121 -1.42512844 -7.08350639 -7.70831354  5.48286415  5.48286415  4.85805691 -7.70831354 -0.80032121 -1.42512845 -0.80032121; 
 4.85805691  4.85805681 -7.08350658  5.48286415 -7.70831382 -7.08350658 -0.80032121 -1.42512845 -7.08350639 -1.42512844  5.48286415 -7.70831354  4.85805691  5.48286415 -0.80032121 -7.70831354 -0.80032121 -1.42512845];
  nglob = 18;
elseif fcn == 'sh5'  % Shekel 5
  u = [0; 0; 0; 0];
  v = [10; 10; 10; 10]; 
%  v = Inf*ones(4,1); u = -v;
  fglob = -10.1531996790582;
  xglob = [4; 4; 4; 4];
  nglob = 1;
elseif fcn == 'sh7'  % Shekel 7
  u = [0; 0; 0; 0];
  v = [10; 10; 10; 10]; 
%  v = Inf*ones(4,1); u = -v;
  fglob = -10.4029405668187;
  xglob = [4; 4; 4; 4];
  nglob = 1;
elseif fcn == 's10'  % Shekel 10
  u = [0; 0; 0; 0];
  v = [10; 10; 10; 10]; 
%  v = Inf*ones(4,1); u = -v;
  fglob = -10.5364098166920;
  xglob = [4; 4; 4; 4];
elseif fcn == 'hm3'  % Hartman 3
  u = [0; 0; 0];
  v = [1; 1; 1]; 
%  v = Inf*ones(3,1); u = -v;
  fglob = -3.86278214782076;
  xglob = [0.1; 0.55592003; 0.85218259];
  nglob = 1;
elseif fcn == 'hm6'  % Hartman 6
  u = [0; 0; 0; 0; 0; 0];
  v = [1; 1; 1; 1; 1; 1]; 
%  v = Inf*ones(6,1); u = -v;
  fglob = -3.32236801141551;
  xglob = [0.20168952;  0.15001069;  0.47687398;  0.27533243;  0.31165162;  0.65730054];
  nglob = 1;
elseif fcn == 'ad4'  % adsorption problem
  n = 4;
  u = [0; 0; 0; 0];
  v = [10000; 200; 10; 1.5];
elseif fcn == 'ros'  % Rosenbrock 
  u = [-2; -2];
  v = [8; 8];
  fac=100;
  u = fac*[-1; -1];
  v = fac*[2; 2];
  v = [2.048; 2.048]; u = -v;
  fglob = 0;
  xglob = [1; 1];
  nglob = 1;
elseif fcn == 'mla'  % Mladineo's function
  u = 0.01*ones(dimmla,1);
  v = ones(dimmla,1);
  nglob = 1;
  if dimmla == 2
    fglob = 0.000170;
    xglob = [0.011527; 0.014405];
  end
elseif fcn == 'sgr'  % simplified Griewank function + 1
  n = dimsgr;
  u = -ones(dimsgr,1);
  v = 4*ones(dimsgr,1);
  fglob = 1;
  xglob = zeros(dimsgr,1);
  nglob = 1;
elseif fcn == 'sch'  % Sch"affler's function + 1
  n = 50; 
  u = -1.05*ones(50,1);
  v = 2.95*ones(50,1);
  fglob = 1;
  xglob = zeros(50,1);
  nglob = 1;
elseif fcn == 'dj1'
  u = [-5.12; -5.12; -5.12];
  v = [5.12; 5.12; 5.12];
  fglob = 0;
  xglob = zeros(3,1);
  nglob = 1;
elseif fcn == 'dj3'
  u = [-5.12; -5.12; -5.12; -5.12; -5.12];
  v = [5.12; 5.12; 5.12; 5.12; 5.12]; 
  fglob = 0;
elseif fcn == 'dj4'
  u = -1.28*ones(30,1);
  v = 1.28*ones(30,1);
  fglob = 15;
elseif fcn == 'dj5'
  u = [-65.536; -65.536]; 
  v = [65.536; 65.536]; 
  fglob = 0.99800383881865;
  xglob = [-32; -32];
  nglob = 1;
elseif fcn == 'cor'
  u = -1000*ones(4,1); 
  v = 1000*ones(4,1);
  fglob = 0;
elseif fcn == 'gri'
  u = -400*ones(10,1);
  v = 400*ones(10,1);
  fglob = 0;
  xglob = zeros(10,1);
elseif fcn == 'zim'
  u = zeros(2,1);
  v = [7; 6];
  fglob = 0;
  xglob = [7; 2];
elseif fcn == 'pol'
%  u = -300*ones(9,1);
%  v = 150*ones(9,1);
  fglob = 0;
  u = -200000*ones(17,1);
  v = 220000*ones(17,1);
end
